% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/meta_data.R
\name{read.neurons.fafb}
\alias{read.neurons.fafb}
\alias{fafb_get_meta}
\title{Read neurons from CATMAID with extra meta-data}
\usage{
read.neurons.fafb(
  skids,
  meta = c("neuron name", "whimsical name", "cell type", "cell body fiber",
    "ItoLee_Lineage", "ItoLee_Hemilineage", "Hartenstein_Lineage",
    "Hartenstein_Hemilineage", "transmitter", "tracing status", "hemibrain match",
    "synonym", "paper", "citation"),
  sub = ".*:",
  OmitFailures = TRUE,
  batch = FALSE,
  catmaid_get_compact_skeleton = TRUE,
  ...
)

fafb_get_meta(
  skids,
  meta = c("neuron name", "whimsical name", "cell type", "cell body fiber",
    "ItoLee_Lineage", "ItoLee_Hemilineage", "Hartenstein_Lineage",
    "Hartenstein_Hemilineage", "transmitter", "tracing status", "hemibrain match",
    "flywire id", "flywire xyz", "FAFB xyz", "synonym", "paper", "citation"),
  sub = ".*:",
  OmitFailures = TRUE,
  ...
)
}
\arguments{
\item{skids}{One or more numeric skeleton ids or a character vector defining
a query (see \code{\link[catmaid]{catmaid_skids}} or examples for the syntax).}

\item{meta}{a vector of meta-annotations to query.
The annotations labelled by these meta-annotations will appear as
entries in the \code{data.frame} attached to the returned \code{neuronlist}.}

\item{sub}{what to remove from pulled annotations, to clean them up a little.
Can be set to "" if you do not wish to remove anything.}

\item{OmitFailures}{Whether to omit neurons for which \code{FUN} gives an
error. The default value (\code{NA}) will result in \code{\link{nlapply}}
stopping with an error message the moment there is an error. For other
values, see details.}

\item{batch}{numeric, if \code{FALSE} or \code{0} neurons are read from CATMAID without being batched.
If a number, neurons are read in batches of size \code{batch}. If \code{batch} is set to \code{TRUE}, a batch size of
1000 is used. This can help overcome server time out errors.}

\item{catmaid_get_compact_skeleton}{whether to use \code{catmaid::catmaid_get_compact_skeleton} or \code{catmaid::read.neurons.catmaid} to obtain neuron data. In the former case,
connectors and tags are not returned.}

\item{...}{Additional arguments passed to the \code{\link[catmaid]{catmaid_fetch}}
function}
}
\description{
Use \code{read.neurons.catmaid} to acquire neurons from a CATMAID instance.
In addition, include as meta-data certain annotations that these neurons have. To select which
annotations appear as entries in the neurons' meta-data, select 'meta-annotations' to appear as the
data field. By default, meta-annotations for developmental lineage identities are used,
to get the lineage / hemilineage to which a FAFB Drosophila neuron belongs.
}
\examples{
\donttest{
\dontrun{
# Get some information on a published neuron
## 11519370 was pubished first in Dolan et al. 2019
meta = fafb_get_meta("11519370")

# We can get all of the lineage annotations made in the FAFB dataset
## These come from two different naming schemes, one by Volker Hartenstein
## and another by the groups' of K. Ito and T. Lee.
fafb.neurons.lineage =
read.neurons.fafb("annotation:Lineage_annotated")
}}
}
